# Masonite
Core files for the python framework

[![Build Status](https://travis-ci.org/MasoniteFramework/core.svg?branch=master)](https://travis-ci.org/MasoniteFramework/core) <img src="https://img.shields.io/badge/coverage-79%25-green.svg">

To get started with this repo, [read the CONTRIBUTING.md file on the masonite repo](https://github.com/josephmancuso/masonite/blob/master/CONTRIBUTING.md)
